==> derby-0.1.0.tgz: package/examples/chat/lib/server/index.js <==
var MAX_AGE_ONE_YEAR, chat, derby, express, gzip, path, publicPath, root, server, staticPages, store;
path = require('path');
express = require('express');
derby = require('derby');
gzip = require('connect-gzip');
chat = require('../chat');
MAX_AGE_ONE_YEAR = {
  maxAge: 1000 * 60 * 60 * 24 * 365
};
root = path.dirname(path.dirname(__dirname));
publicPath = path.join(root, 'public');
staticPages = derby.createStatic(root);
(server = express.createServer()).use(gzip.staticGzip(publicPath, MAX_AGE_ONE_YEAR)).use(express.favicon()).use(express.cookieParser()).use(express.session({
  secret: 'dont_tell',
  cookie: MAX_AGE_ONE_YEAR
})).use(chat.session()).use(gzip.gzip()).use(chat.router()).use(server.router);
server.configure('development', function() {
  return server.error(function(err, req, res, next) {
    if (err) {
      console.log(err.stack ? err.stack : err);
    }
    return next(err);
  });
});
server.error(function(err, req, res) {
  var message, status;
  message = err.message || err.toString();
  status = parseInt(message);
  if (status === 404) {
    return staticPages.render('404', res, {
      url: req.url
    }, 404);
  } else {
    return res.send((400 <= status && status < 600) ? status : 500);
  }
});
server.all('*', function(req) {
  throw "404: " + req.url;
});
store = chat.createStore({
  redis: {
    db: 2
  },
  listen: server
});
store.flush();
server.listen(3002);
console.log('Express server started in %s mode', server.settings.env);
console.log('Go to: http://localhost:%d/', server.address().port);

==> derby-0.1.3.tgz: package/examples/chat/lib/server/index.js <==
var MAX_AGE_ONE_YEAR, chat, derby, express, gzip, path, publicPath, root, server, staticPages, store;

path = require('path');

express = require('express');

derby = require('derby');

gzip = require('connect-gzip');

chat = require('../chat');

MAX_AGE_ONE_YEAR = {
  maxAge: 1000 * 60 * 60 * 24 * 365
};

root = path.dirname(path.dirname(__dirname));

publicPath = path.join(root, 'public');

staticPages = derby.createStatic(root);

(server = express.createServer()).use(gzip.staticGzip(publicPath, MAX_AGE_ONE_YEAR)).use(express.favicon()).use(express.cookieParser()).use(express.session({
  secret: 'dont_tell',
  cookie: MAX_AGE_ONE_YEAR
})).use(chat.session()).use(gzip.gzip()).use(chat.router()).use(server.router);

server.configure('development', function() {
  return server.error(function(err, req, res, next) {
    if (err) console.log(err.stack ? err.stack : err);
    return next(err);
  });
});

server.error(function(err, req, res) {
  var message, status;
  message = err.message || err.toString();
  status = parseInt(message);
  if (status === 404) {
    return staticPages.render('404', res, {
      url: req.url
    }, 404);
  } else {
    return res.send((400 <= status && status < 600) ? status : 500);
  }
});

server.all('*', function(req) {
  throw "404: " + req.url;
});

store = chat.createStore({
  redis: {
    db: 2
  },
  listen: server
});

store.flush();

server.listen(3002);

console.log('Express server started in %s mode', server.settings.env);

console.log('Go to: http://localhost:%d/', server.address().port);
